@@ -8,12 +8,12 @@ photosynthesis_outputs c4photoC(
     double const leaf_temperature,
     double const ambient_temperature,
     double const relative_humidity,
-    double const vmax,
+    double const Vcmax_at_25,
     double const alpha,
     double const kparm,
     double const theta,
     double const beta,
-    double const Rd,
+    double const RL,
     double const bb0,
     double const bb1,
     double const Gs_min,
